# FortanixSdkmsRestApi.StatsApi

All URIs are relative to *https://apps.smartkey.io*

Method | HTTP request | Description
------------- | ------------- | -------------
[**getAppStats**](StatsApi.md#getAppStats) | **GET** /sys/v1/stats/{app-id}/app | Get transaction statistics for a specific application
[**getAppsStats**](StatsApi.md#getAppsStats) | **GET** /sys/v1/stats/apps | Get app aggregate transaction statistics
[**getGroupStats**](StatsApi.md#getGroupStats) | **GET** /sys/v1/stats/{group-id}/group | Get transaction statistics for a specific group
[**getGroupsStats**](StatsApi.md#getGroupsStats) | **GET** /sys/v1/stats/groups | Get group aggregate transaction statistics
[**getSecurityObjectStats**](StatsApi.md#getSecurityObjectStats) | **GET** /sys/v1/stats/{key-id}/key | Get transaction statistics for a specific security object


<a name="getAppStats"></a>
# **getAppStats**
> StatsResponse getAppStats(appId, opts)

Get transaction statistics for a specific application

This API is for obtaining transaction statistics for a specific application. API supports query parameters for fetchings stats for specific time period and with number of data points desired.

### Example
```javascript
var FortanixSdkmsRestApi = require('fortanix_sdkms_rest_api');
var defaultClient = FortanixSdkmsRestApi.ApiClient.instance;

// Configure API key authorization: bearerToken
var bearerToken = defaultClient.authentications['bearerToken'];
bearerToken.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//bearerToken.apiKeyPrefix = 'Token';

var apiInstance = new FortanixSdkmsRestApi.StatsApi();

var appId = "appId_example"; // String | Application Identifier

var opts = { 
  'rangeFrom': 56, // Number | Starting time for search , this is EPOCH value
  'rangeTo': 56, // Number | Ending time for search , this is EPOCH value
  'numPoints': 56 // Number | Number of data points desired
};

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.getAppStats(appId, opts, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **appId** | **String**| Application Identifier | 
 **rangeFrom** | **Number**| Starting time for search , this is EPOCH value | [optional] 
 **rangeTo** | **Number**| Ending time for search , this is EPOCH value | [optional] 
 **numPoints** | **Number**| Number of data points desired | [optional] 

### Return type

[**StatsResponse**](StatsResponse.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getAppsStats"></a>
# **getAppsStats**
> StatsResponse getAppsStats(opts)

Get app aggregate transaction statistics

This is for obtaining app level aggregate transaction statistics to find top apps by transaction. API supports query parameters for fetchings stats for specific time period, for maximum top count and with number of data points desired.

### Example
```javascript
var FortanixSdkmsRestApi = require('fortanix_sdkms_rest_api');
var defaultClient = FortanixSdkmsRestApi.ApiClient.instance;

// Configure API key authorization: bearerToken
var bearerToken = defaultClient.authentications['bearerToken'];
bearerToken.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//bearerToken.apiKeyPrefix = 'Token';

var apiInstance = new FortanixSdkmsRestApi.StatsApi();

var opts = { 
  'rangeFrom': 56, // Number | Starting time for search , this is EPOCH value
  'rangeTo': 56, // Number | Ending time for search , this is EPOCH value
  'topCount': 56, // Number | Maximum top count for statistics query
  'numPoints': 56 // Number | Number of data points desired
};

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.getAppsStats(opts, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **rangeFrom** | **Number**| Starting time for search , this is EPOCH value | [optional] 
 **rangeTo** | **Number**| Ending time for search , this is EPOCH value | [optional] 
 **topCount** | **Number**| Maximum top count for statistics query | [optional] 
 **numPoints** | **Number**| Number of data points desired | [optional] 

### Return type

[**StatsResponse**](StatsResponse.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getGroupStats"></a>
# **getGroupStats**
> StatsResponse getGroupStats(groupId, opts)

Get transaction statistics for a specific group

This API is for obtaining transaction statistics for a specific group. API supports query parameters for fetchings stats for specific time period and with number of data points desired.

### Example
```javascript
var FortanixSdkmsRestApi = require('fortanix_sdkms_rest_api');
var defaultClient = FortanixSdkmsRestApi.ApiClient.instance;

// Configure API key authorization: bearerToken
var bearerToken = defaultClient.authentications['bearerToken'];
bearerToken.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//bearerToken.apiKeyPrefix = 'Token';

var apiInstance = new FortanixSdkmsRestApi.StatsApi();

var groupId = "groupId_example"; // String | Group Identifier

var opts = { 
  'rangeFrom': 56, // Number | Starting time for search , this is EPOCH value
  'rangeTo': 56, // Number | Ending time for search , this is EPOCH value
  'numPoints': 56 // Number | Number of data points desired
};

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.getGroupStats(groupId, opts, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **groupId** | **String**| Group Identifier | 
 **rangeFrom** | **Number**| Starting time for search , this is EPOCH value | [optional] 
 **rangeTo** | **Number**| Ending time for search , this is EPOCH value | [optional] 
 **numPoints** | **Number**| Number of data points desired | [optional] 

### Return type

[**StatsResponse**](StatsResponse.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getGroupsStats"></a>
# **getGroupsStats**
> StatsResponse getGroupsStats(opts)

Get group aggregate transaction statistics

This is for obtaining group level aggregate transaction statistics to find top groups by transaction. API supports query parameters for fetchings stats for specific time period, for maximum top count and with number of data points desired.

### Example
```javascript
var FortanixSdkmsRestApi = require('fortanix_sdkms_rest_api');
var defaultClient = FortanixSdkmsRestApi.ApiClient.instance;

// Configure API key authorization: bearerToken
var bearerToken = defaultClient.authentications['bearerToken'];
bearerToken.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//bearerToken.apiKeyPrefix = 'Token';

var apiInstance = new FortanixSdkmsRestApi.StatsApi();

var opts = { 
  'rangeFrom': 56, // Number | Starting time for search , this is EPOCH value
  'rangeTo': 56, // Number | Ending time for search , this is EPOCH value
  'topCount': 56, // Number | Maximum top count for statistics query
  'numPoints': 56 // Number | Number of data points desired
};

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.getGroupsStats(opts, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **rangeFrom** | **Number**| Starting time for search , this is EPOCH value | [optional] 
 **rangeTo** | **Number**| Ending time for search , this is EPOCH value | [optional] 
 **topCount** | **Number**| Maximum top count for statistics query | [optional] 
 **numPoints** | **Number**| Number of data points desired | [optional] 

### Return type

[**StatsResponse**](StatsResponse.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getSecurityObjectStats"></a>
# **getSecurityObjectStats**
> StatsResponse getSecurityObjectStats(keyId, opts)

Get transaction statistics for a specific security object

This API is for obtaining transaction statistics for a specific security object. API supports query parameters for fetchings stats for specific time period and with number of data points desired.

### Example
```javascript
var FortanixSdkmsRestApi = require('fortanix_sdkms_rest_api');
var defaultClient = FortanixSdkmsRestApi.ApiClient.instance;

// Configure API key authorization: bearerToken
var bearerToken = defaultClient.authentications['bearerToken'];
bearerToken.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//bearerToken.apiKeyPrefix = 'Token';

var apiInstance = new FortanixSdkmsRestApi.StatsApi();

var keyId = "keyId_example"; // String | kid of security object

var opts = { 
  'rangeFrom': 56, // Number | Starting time for search , this is EPOCH value
  'rangeTo': 56, // Number | Ending time for search , this is EPOCH value
  'numPoints': 56 // Number | Number of data points desired
};

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.getSecurityObjectStats(keyId, opts, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **keyId** | **String**| kid of security object | 
 **rangeFrom** | **Number**| Starting time for search , this is EPOCH value | [optional] 
 **rangeTo** | **Number**| Ending time for search , this is EPOCH value | [optional] 
 **numPoints** | **Number**| Number of data points desired | [optional] 

### Return type

[**StatsResponse**](StatsResponse.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

