/**
 * Fortanix SDKMS REST API
 * This is a set of REST APIs for accessing the Fortanix Self-Defending Key Management System. This includes APIs for managing accounts, and for performing cryptographic and key management operations. 
 *
 * OpenAPI spec version: 1.0.0-20200608
 * Contact: support@fortanix.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 *
 * Swagger Codegen version: 2.3.0-SNAPSHOT
 *
 * Do not edit the class manually.
 *
 */

(function(root, factory) {
  if (typeof define === 'function' && define.amd) {
    // AMD. Register as an anonymous module.
    define(['ApiClient', 'model/ChildAccountUser', 'model/ChildAccountUserRequest', 'model/Error'], factory);
  } else if (typeof module === 'object' && module.exports) {
    // CommonJS-like environments that support module.exports, like Node.
    module.exports = factory(require('../ApiClient'), require('../model/ChildAccountUser'), require('../model/ChildAccountUserRequest'), require('../model/Error'));
  } else {
    // Browser globals (root is window)
    if (!root.FortanixSdkmsRestApi) {
      root.FortanixSdkmsRestApi = {};
    }
    root.FortanixSdkmsRestApi.ChildAccountUsersApi = factory(root.FortanixSdkmsRestApi.ApiClient, root.FortanixSdkmsRestApi.ChildAccountUser, root.FortanixSdkmsRestApi.ChildAccountUserRequest, root.FortanixSdkmsRestApi.Error);
  }
}(this, function(ApiClient, ChildAccountUser, ChildAccountUserRequest, Error) {
  'use strict';

  /**
   * ChildAccountUsers service.
   * @module api/ChildAccountUsersApi
   * @version 1.0.0-20200608
   */

  /**
   * Constructs a new ChildAccountUsersApi. 
   * @alias module:api/ChildAccountUsersApi
   * @class
   * @param {module:ApiClient} apiClient Optional API client implementation to use,
   * default to {@link module:ApiClient#instance} if unspecified.
   */
  var exports = function(apiClient) {
    this.apiClient = apiClient || ApiClient.instance;


    /**
     * Callback function to receive the result of the createChildAccountUser operation.
     * @callback module:api/ChildAccountUsersApi~createChildAccountUserCallback
     * @param {String} error Error message, if any.
     * @param {module:model/ChildAccountUser} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */

    /**
     * Create a new user user in a child account
     * Create a new user user in a child account.
     * @param {module:model/ChildAccountUserRequest} body User in child account
     * @param {module:api/ChildAccountUsersApi~createChildAccountUserCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link module:model/ChildAccountUser}
     */
    this.createChildAccountUser = function(body, callback) {
      var postBody = body;

      // verify the required parameter 'body' is set
      if (body === undefined || body === null) {
        throw new Error("Missing the required parameter 'body' when calling createChildAccountUser");
      }


      var pathParams = {
      };
      var queryParams = {
      };
      var collectionQueryParams = {
      };
      var headerParams = {
      };
      var formParams = {
      };

      var authNames = ['bearerToken'];
      var contentTypes = [];
      var accepts = ['application/json'];
      var returnType = ChildAccountUser;

      return this.apiClient.callApi(
        '/sys/v1/users/child_account', 'POST',
        pathParams, queryParams, collectionQueryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType, callback
      );
    }

    /**
     * Callback function to receive the result of the deleteChildAccountUser operation.
     * @callback module:api/ChildAccountUsersApi~deleteChildAccountUserCallback
     * @param {String} error Error message, if any.
     * @param data This operation does not return a value.
     * @param {String} response The complete HTTP response.
     */

    /**
     * Completely delete a user in child account
     * Completely delete a user in child account.
     * @param {String} userId User Identifier
     * @param {module:api/ChildAccountUsersApi~deleteChildAccountUserCallback} callback The callback function, accepting three arguments: error, data, response
     */
    this.deleteChildAccountUser = function(userId, callback) {
      var postBody = null;

      // verify the required parameter 'userId' is set
      if (userId === undefined || userId === null) {
        throw new Error("Missing the required parameter 'userId' when calling deleteChildAccountUser");
      }


      var pathParams = {
        'user-id': userId
      };
      var queryParams = {
      };
      var collectionQueryParams = {
      };
      var headerParams = {
      };
      var formParams = {
      };

      var authNames = ['bearerToken'];
      var contentTypes = [];
      var accepts = ['application/json'];
      var returnType = null;

      return this.apiClient.callApi(
        '/sys/v1/users/child_account/{user-id}', 'DELETE',
        pathParams, queryParams, collectionQueryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType, callback
      );
    }

    /**
     * Callback function to receive the result of the getAllChildAccountUsers operation.
     * @callback module:api/ChildAccountUsersApi~getAllChildAccountUsersCallback
     * @param {String} error Error message, if any.
     * @param {Array.<module:model/ChildAccountUser>} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */

    /**
     * Get all users in a child account
     * Get all users in a child account
     * @param {String} accountId Account Identifier
     * @param {module:api/ChildAccountUsersApi~getAllChildAccountUsersCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link Array.<module:model/ChildAccountUser>}
     */
    this.getAllChildAccountUsers = function(accountId, callback) {
      var postBody = null;

      // verify the required parameter 'accountId' is set
      if (accountId === undefined || accountId === null) {
        throw new Error("Missing the required parameter 'accountId' when calling getAllChildAccountUsers");
      }


      var pathParams = {
        'account-id': accountId
      };
      var queryParams = {
      };
      var collectionQueryParams = {
      };
      var headerParams = {
      };
      var formParams = {
      };

      var authNames = ['bearerToken'];
      var contentTypes = [];
      var accepts = ['application/json'];
      var returnType = [ChildAccountUser];

      return this.apiClient.callApi(
        '/sys/v1/users/child_account/{account-id}/all', 'GET',
        pathParams, queryParams, collectionQueryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType, callback
      );
    }

    /**
     * Callback function to receive the result of the getChildAccountUser operation.
     * @callback module:api/ChildAccountUsersApi~getChildAccountUserCallback
     * @param {String} error Error message, if any.
     * @param {module:model/ChildAccountUser} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */

    /**
     * Get a specific child account user
     * @param {String} userId User Identifier
     * @param {module:api/ChildAccountUsersApi~getChildAccountUserCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link module:model/ChildAccountUser}
     */
    this.getChildAccountUser = function(userId, callback) {
      var postBody = null;

      // verify the required parameter 'userId' is set
      if (userId === undefined || userId === null) {
        throw new Error("Missing the required parameter 'userId' when calling getChildAccountUser");
      }


      var pathParams = {
        'user-id': userId
      };
      var queryParams = {
      };
      var collectionQueryParams = {
      };
      var headerParams = {
      };
      var formParams = {
      };

      var authNames = ['bearerToken'];
      var contentTypes = [];
      var accepts = ['application/json'];
      var returnType = ChildAccountUser;

      return this.apiClient.callApi(
        '/sys/v1/users/child_account/{user-id}', 'GET',
        pathParams, queryParams, collectionQueryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType, callback
      );
    }

    /**
     * Callback function to receive the result of the updateChildAccountUser operation.
     * @callback module:api/ChildAccountUsersApi~updateChildAccountUserCallback
     * @param {String} error Error message, if any.
     * @param {module:model/ChildAccountUser} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */

    /**
     * Update a child account user
     * Change a child account user&#39;s properties.
     * @param {String} userId User Identifier
     * @param {module:model/ChildAccountUserRequest} body User in child account
     * @param {module:api/ChildAccountUsersApi~updateChildAccountUserCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link module:model/ChildAccountUser}
     */
    this.updateChildAccountUser = function(userId, body, callback) {
      var postBody = body;

      // verify the required parameter 'userId' is set
      if (userId === undefined || userId === null) {
        throw new Error("Missing the required parameter 'userId' when calling updateChildAccountUser");
      }

      // verify the required parameter 'body' is set
      if (body === undefined || body === null) {
        throw new Error("Missing the required parameter 'body' when calling updateChildAccountUser");
      }


      var pathParams = {
        'user-id': userId
      };
      var queryParams = {
      };
      var collectionQueryParams = {
      };
      var headerParams = {
      };
      var formParams = {
      };

      var authNames = ['bearerToken'];
      var contentTypes = [];
      var accepts = ['application/json'];
      var returnType = ChildAccountUser;

      return this.apiClient.callApi(
        '/sys/v1/users/child_account/{user-id}', 'PATCH',
        pathParams, queryParams, collectionQueryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType, callback
      );
    }
  };

  return exports;
}));
