/**
 * Fortanix SDKMS REST API
 * This is a set of REST APIs for accessing the Fortanix Self-Defending Key Management System. This includes APIs for managing accounts, and for performing cryptographic and key management operations. 
 *
 * OpenAPI spec version: 1.0.0-20200608
 * Contact: support@fortanix.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 *
 * Swagger Codegen version: 2.3.0-SNAPSHOT
 *
 * Do not edit the class manually.
 *
 */

(function(root, factory) {
  if (typeof define === 'function' && define.amd) {
    // AMD. Register as an anonymous module.
    define(['ApiClient', 'model/Error', 'model/StatsResponse'], factory);
  } else if (typeof module === 'object' && module.exports) {
    // CommonJS-like environments that support module.exports, like Node.
    module.exports = factory(require('../ApiClient'), require('../model/Error'), require('../model/StatsResponse'));
  } else {
    // Browser globals (root is window)
    if (!root.FortanixSdkmsRestApi) {
      root.FortanixSdkmsRestApi = {};
    }
    root.FortanixSdkmsRestApi.StatsApi = factory(root.FortanixSdkmsRestApi.ApiClient, root.FortanixSdkmsRestApi.Error, root.FortanixSdkmsRestApi.StatsResponse);
  }
}(this, function(ApiClient, Error, StatsResponse) {
  'use strict';

  /**
   * Stats service.
   * @module api/StatsApi
   * @version 1.0.0-20200608
   */

  /**
   * Constructs a new StatsApi. 
   * @alias module:api/StatsApi
   * @class
   * @param {module:ApiClient} apiClient Optional API client implementation to use,
   * default to {@link module:ApiClient#instance} if unspecified.
   */
  var exports = function(apiClient) {
    this.apiClient = apiClient || ApiClient.instance;


    /**
     * Callback function to receive the result of the getAppStats operation.
     * @callback module:api/StatsApi~getAppStatsCallback
     * @param {String} error Error message, if any.
     * @param {module:model/StatsResponse} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */

    /**
     * Get transaction statistics for a specific application
     * This API is for obtaining transaction statistics for a specific application. API supports query parameters for fetchings stats for specific time period and with number of data points desired.
     * @param {String} appId Application Identifier
     * @param {Object} opts Optional parameters
     * @param {Number} opts.rangeFrom Starting time for search , this is EPOCH value
     * @param {Number} opts.rangeTo Ending time for search , this is EPOCH value
     * @param {Number} opts.numPoints Number of data points desired
     * @param {module:api/StatsApi~getAppStatsCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link module:model/StatsResponse}
     */
    this.getAppStats = function(appId, opts, callback) {
      opts = opts || {};
      var postBody = null;

      // verify the required parameter 'appId' is set
      if (appId === undefined || appId === null) {
        throw new Error("Missing the required parameter 'appId' when calling getAppStats");
      }


      var pathParams = {
        'app-id': appId
      };
      var queryParams = {
        'range_from': opts['rangeFrom'],
        'range_to': opts['rangeTo'],
        'num_points': opts['numPoints'],
      };
      var collectionQueryParams = {
      };
      var headerParams = {
      };
      var formParams = {
      };

      var authNames = ['bearerToken'];
      var contentTypes = [];
      var accepts = ['application/json'];
      var returnType = StatsResponse;

      return this.apiClient.callApi(
        '/sys/v1/stats/{app-id}/app', 'GET',
        pathParams, queryParams, collectionQueryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType, callback
      );
    }

    /**
     * Callback function to receive the result of the getAppsStats operation.
     * @callback module:api/StatsApi~getAppsStatsCallback
     * @param {String} error Error message, if any.
     * @param {module:model/StatsResponse} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */

    /**
     * Get app aggregate transaction statistics
     * This is for obtaining app level aggregate transaction statistics to find top apps by transaction. API supports query parameters for fetchings stats for specific time period, for maximum top count and with number of data points desired.
     * @param {Object} opts Optional parameters
     * @param {Number} opts.rangeFrom Starting time for search , this is EPOCH value
     * @param {Number} opts.rangeTo Ending time for search , this is EPOCH value
     * @param {Number} opts.topCount Maximum top count for statistics query
     * @param {Number} opts.numPoints Number of data points desired
     * @param {module:api/StatsApi~getAppsStatsCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link module:model/StatsResponse}
     */
    this.getAppsStats = function(opts, callback) {
      opts = opts || {};
      var postBody = null;


      var pathParams = {
      };
      var queryParams = {
        'range_from': opts['rangeFrom'],
        'range_to': opts['rangeTo'],
        'top_count': opts['topCount'],
        'num_points': opts['numPoints'],
      };
      var collectionQueryParams = {
      };
      var headerParams = {
      };
      var formParams = {
      };

      var authNames = ['bearerToken'];
      var contentTypes = [];
      var accepts = ['application/json'];
      var returnType = StatsResponse;

      return this.apiClient.callApi(
        '/sys/v1/stats/apps', 'GET',
        pathParams, queryParams, collectionQueryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType, callback
      );
    }

    /**
     * Callback function to receive the result of the getGroupStats operation.
     * @callback module:api/StatsApi~getGroupStatsCallback
     * @param {String} error Error message, if any.
     * @param {module:model/StatsResponse} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */

    /**
     * Get transaction statistics for a specific group
     * This API is for obtaining transaction statistics for a specific group. API supports query parameters for fetchings stats for specific time period and with number of data points desired.
     * @param {String} groupId Group Identifier
     * @param {Object} opts Optional parameters
     * @param {Number} opts.rangeFrom Starting time for search , this is EPOCH value
     * @param {Number} opts.rangeTo Ending time for search , this is EPOCH value
     * @param {Number} opts.numPoints Number of data points desired
     * @param {module:api/StatsApi~getGroupStatsCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link module:model/StatsResponse}
     */
    this.getGroupStats = function(groupId, opts, callback) {
      opts = opts || {};
      var postBody = null;

      // verify the required parameter 'groupId' is set
      if (groupId === undefined || groupId === null) {
        throw new Error("Missing the required parameter 'groupId' when calling getGroupStats");
      }


      var pathParams = {
        'group-id': groupId
      };
      var queryParams = {
        'range_from': opts['rangeFrom'],
        'range_to': opts['rangeTo'],
        'num_points': opts['numPoints'],
      };
      var collectionQueryParams = {
      };
      var headerParams = {
      };
      var formParams = {
      };

      var authNames = ['bearerToken'];
      var contentTypes = [];
      var accepts = ['application/json'];
      var returnType = StatsResponse;

      return this.apiClient.callApi(
        '/sys/v1/stats/{group-id}/group', 'GET',
        pathParams, queryParams, collectionQueryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType, callback
      );
    }

    /**
     * Callback function to receive the result of the getGroupsStats operation.
     * @callback module:api/StatsApi~getGroupsStatsCallback
     * @param {String} error Error message, if any.
     * @param {module:model/StatsResponse} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */

    /**
     * Get group aggregate transaction statistics
     * This is for obtaining group level aggregate transaction statistics to find top groups by transaction. API supports query parameters for fetchings stats for specific time period, for maximum top count and with number of data points desired.
     * @param {Object} opts Optional parameters
     * @param {Number} opts.rangeFrom Starting time for search , this is EPOCH value
     * @param {Number} opts.rangeTo Ending time for search , this is EPOCH value
     * @param {Number} opts.topCount Maximum top count for statistics query
     * @param {Number} opts.numPoints Number of data points desired
     * @param {module:api/StatsApi~getGroupsStatsCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link module:model/StatsResponse}
     */
    this.getGroupsStats = function(opts, callback) {
      opts = opts || {};
      var postBody = null;


      var pathParams = {
      };
      var queryParams = {
        'range_from': opts['rangeFrom'],
        'range_to': opts['rangeTo'],
        'top_count': opts['topCount'],
        'num_points': opts['numPoints'],
      };
      var collectionQueryParams = {
      };
      var headerParams = {
      };
      var formParams = {
      };

      var authNames = ['bearerToken'];
      var contentTypes = [];
      var accepts = ['application/json'];
      var returnType = StatsResponse;

      return this.apiClient.callApi(
        '/sys/v1/stats/groups', 'GET',
        pathParams, queryParams, collectionQueryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType, callback
      );
    }

    /**
     * Callback function to receive the result of the getSecurityObjectStats operation.
     * @callback module:api/StatsApi~getSecurityObjectStatsCallback
     * @param {String} error Error message, if any.
     * @param {module:model/StatsResponse} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */

    /**
     * Get transaction statistics for a specific security object
     * This API is for obtaining transaction statistics for a specific security object. API supports query parameters for fetchings stats for specific time period and with number of data points desired.
     * @param {String} keyId kid of security object
     * @param {Object} opts Optional parameters
     * @param {Number} opts.rangeFrom Starting time for search , this is EPOCH value
     * @param {Number} opts.rangeTo Ending time for search , this is EPOCH value
     * @param {Number} opts.numPoints Number of data points desired
     * @param {module:api/StatsApi~getSecurityObjectStatsCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link module:model/StatsResponse}
     */
    this.getSecurityObjectStats = function(keyId, opts, callback) {
      opts = opts || {};
      var postBody = null;

      // verify the required parameter 'keyId' is set
      if (keyId === undefined || keyId === null) {
        throw new Error("Missing the required parameter 'keyId' when calling getSecurityObjectStats");
      }


      var pathParams = {
        'key-id': keyId
      };
      var queryParams = {
        'range_from': opts['rangeFrom'],
        'range_to': opts['rangeTo'],
        'num_points': opts['numPoints'],
      };
      var collectionQueryParams = {
      };
      var headerParams = {
      };
      var formParams = {
      };

      var authNames = ['bearerToken'];
      var contentTypes = [];
      var accepts = ['application/json'];
      var returnType = StatsResponse;

      return this.apiClient.callApi(
        '/sys/v1/stats/{key-id}/key', 'GET',
        pathParams, queryParams, collectionQueryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType, callback
      );
    }
  };

  return exports;
}));
