/**
 * Fortanix SDKMS REST API
 * This is a set of REST APIs for accessing the Fortanix Self-Defending Key Management System. This includes APIs for managing accounts, and for performing cryptographic and key management operations. 
 *
 * OpenAPI spec version: 1.0.0-20200608
 * Contact: support@fortanix.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 *
 * Swagger Codegen version: 2.3.0-SNAPSHOT
 *
 * Do not edit the class manually.
 *
 */

(function(root, factory) {
  if (typeof define === 'function' && define.amd) {
    // AMD. Register as an anonymous module.
    define(['ApiClient', 'model/DsaOptions', 'model/EllipticCurve', 'model/FpeOptions', 'model/KeyObjectState', 'model/KeyOperations', 'model/ObjectType', 'model/RotationPolicy', 'model/RsaOptions'], factory);
  } else if (typeof module === 'object' && module.exports) {
    // CommonJS-like environments that support module.exports, like Node.
    module.exports = factory(require('../ApiClient'), require('./DsaOptions'), require('./EllipticCurve'), require('./FpeOptions'), require('./KeyObjectState'), require('./KeyOperations'), require('./ObjectType'), require('./RotationPolicy'), require('./RsaOptions'));
  } else {
    // Browser globals (root is window)
    if (!root.FortanixSdkmsRestApi) {
      root.FortanixSdkmsRestApi = {};
    }
    root.FortanixSdkmsRestApi.SobjectRequest = factory(root.FortanixSdkmsRestApi.ApiClient, root.FortanixSdkmsRestApi.DsaOptions, root.FortanixSdkmsRestApi.EllipticCurve, root.FortanixSdkmsRestApi.FpeOptions, root.FortanixSdkmsRestApi.KeyObjectState, root.FortanixSdkmsRestApi.KeyOperations, root.FortanixSdkmsRestApi.ObjectType, root.FortanixSdkmsRestApi.RotationPolicy, root.FortanixSdkmsRestApi.RsaOptions);
  }
}(this, function(ApiClient, DsaOptions, EllipticCurve, FpeOptions, KeyObjectState, KeyOperations, ObjectType, RotationPolicy, RsaOptions) {
  'use strict';




  /**
   * The SobjectRequest model module.
   * @module model/SobjectRequest
   * @version 1.0.0-20200608
   */

  /**
   * Constructs a new <code>SobjectRequest</code>.
   * @alias module:model/SobjectRequest
   * @class
   * @param name {String} Name of the security object to create or import. Security object names must be unique within an account.
   * @param objType {module:model/ObjectType} 
   */
  var exports = function(name, objType) {
    var _this = this;

    _this['name'] = name;









    _this['obj_type'] = objType;








  };

  /**
   * Constructs a <code>SobjectRequest</code> from a plain JavaScript object, optionally creating a new instance.
   * Copies all relevant properties from <code>data</code> to <code>obj</code> if supplied or a new instance if not.
   * @param {Object} data The plain JavaScript object bearing properties of interest.
   * @param {module:model/SobjectRequest} obj Optional instance to populate.
   * @return {module:model/SobjectRequest} The populated <code>SobjectRequest</code> instance.
   */
  exports.constructFromObject = function(data, obj) {
    if (data) {
      obj = obj || new exports();

      if (data.hasOwnProperty('name')) {
        obj['name'] = ApiClient.convertToType(data['name'], 'String');
      }
      if (data.hasOwnProperty('description')) {
        obj['description'] = ApiClient.convertToType(data['description'], 'String');
      }
      if (data.hasOwnProperty('key_size')) {
        obj['key_size'] = ApiClient.convertToType(data['key_size'], 'Number');
      }
      if (data.hasOwnProperty('pub_exponent')) {
        obj['pub_exponent'] = ApiClient.convertToType(data['pub_exponent'], 'Number');
      }
      if (data.hasOwnProperty('elliptic_curve')) {
        obj['elliptic_curve'] = EllipticCurve.constructFromObject(data['elliptic_curve']);
      }
      if (data.hasOwnProperty('rsa')) {
        obj['rsa'] = RsaOptions.constructFromObject(data['rsa']);
      }
      if (data.hasOwnProperty('dsa')) {
        obj['dsa'] = DsaOptions.constructFromObject(data['dsa']);
      }
      if (data.hasOwnProperty('fpe')) {
        obj['fpe'] = FpeOptions.constructFromObject(data['fpe']);
      }
      if (data.hasOwnProperty('group_id')) {
        obj['group_id'] = ApiClient.convertToType(data['group_id'], 'String');
      }
      if (data.hasOwnProperty('rotation_policy')) {
        obj['rotation_policy'] = RotationPolicy.constructFromObject(data['rotation_policy']);
      }
      if (data.hasOwnProperty('obj_type')) {
        obj['obj_type'] = ObjectType.constructFromObject(data['obj_type']);
      }
      if (data.hasOwnProperty('key_ops')) {
        obj['key_ops'] = ApiClient.convertToType(data['key_ops'], [KeyOperations]);
      }
      if (data.hasOwnProperty('custom_metadata')) {
        obj['custom_metadata'] = ApiClient.convertToType(data['custom_metadata'], {'String': 'String'});
      }
      if (data.hasOwnProperty('value')) {
        obj['value'] = ApiClient.convertToType(data['value'], 'Blob');
      }
      if (data.hasOwnProperty('enabled')) {
        obj['enabled'] = ApiClient.convertToType(data['enabled'], 'Boolean');
      }
      if (data.hasOwnProperty('transient')) {
        obj['transient'] = ApiClient.convertToType(data['transient'], 'Boolean');
      }
      if (data.hasOwnProperty('deterministic_signatures')) {
        obj['deterministic_signatures'] = ApiClient.convertToType(data['deterministic_signatures'], 'Boolean');
      }
      if (data.hasOwnProperty('state')) {
        obj['state'] = KeyObjectState.constructFromObject(data['state']);
      }
      if (data.hasOwnProperty('deactivation_date')) {
        obj['deactivation_date'] = ApiClient.convertToType(data['deactivation_date'], 'String');
      }
    }
    return obj;
  }

  /**
   * Name of the security object to create or import. Security object names must be unique within an account.
   * @member {String} name
   */
  exports.prototype['name'] = undefined;
  /**
   * Description of the security object to create or import.
   * @member {String} description
   */
  exports.prototype['description'] = undefined;
  /**
   * Size in bits (not bytes) of the security object to create or import. Required for symmetric keys. For DSA keys, it represents the size of `p`; allowed values are 2048 or 3072. Deprecated for RSA keys, specify it in `RsaOptions` instead.
   * @member {Number} key_size
   */
  exports.prototype['key_size'] = undefined;
  /**
   * For RSA keys only. Deprecated. Specify in `RsaOptions` instead. Public exponent to use when generating an RSA key.
   * @member {Number} pub_exponent
   */
  exports.prototype['pub_exponent'] = undefined;
  /**
   * @member {module:model/EllipticCurve} elliptic_curve
   */
  exports.prototype['elliptic_curve'] = undefined;
  /**
   * @member {module:model/RsaOptions} rsa
   */
  exports.prototype['rsa'] = undefined;
  /**
   * @member {module:model/DsaOptions} dsa
   */
  exports.prototype['dsa'] = undefined;
  /**
   * @member {module:model/FpeOptions} fpe
   */
  exports.prototype['fpe'] = undefined;
  /**
   * Group ID (not name) of the security group that this security object should belong to. The user or application creating this security object must be a member of this group. If no group is specified, the default group for the user or application will be used. 
   * @member {String} group_id
   */
  exports.prototype['group_id'] = undefined;
  /**
   * @member {module:model/RotationPolicy} rotation_policy
   */
  exports.prototype['rotation_policy'] = undefined;
  /**
   * @member {module:model/ObjectType} obj_type
   */
  exports.prototype['obj_type'] = undefined;
  /**
   * Optional array of key operations to be enabled for this security object. If this property is not provided, the SDKMS server will provide a default set of key operations. Note that if you provide an empty array, all key operations will be disabled. 
   * @member {Array.<module:model/KeyOperations>} key_ops
   */
  exports.prototype['key_ops'] = undefined;
  /**
   * User-defined metadata for this key. Stored as key-value pairs.
   * @member {Object.<String, String>} custom_metadata
   */
  exports.prototype['custom_metadata'] = undefined;
  /**
   * When importing a security object, this field contains the binary contents to import. When creating a security object, this field is unused. The value of an OPAQUE or CERTIFICATE object is always returned. For other objects, the value is returned only with `/crypto/v1/keys/export` API (if the object is exportable). 
   * @member {Blob} value
   */
  exports.prototype['value'] = undefined;
  /**
   * Whether the new security object should be enabled. Disabled security objects may not perform cryptographic operations. 
   * @member {Boolean} enabled
   */
  exports.prototype['enabled'] = undefined;
  /**
   * If this is true, SDKMS will create a transient key.
   * @member {Boolean} transient
   */
  exports.prototype['transient'] = undefined;
  /**
   * @member {Boolean} deterministic_signatures
   */
  exports.prototype['deterministic_signatures'] = undefined;
  /**
   * @member {module:model/KeyObjectState} state
   */
  exports.prototype['state'] = undefined;
  /**
   * When this object will be deactivated.
   * @member {String} deactivation_date
   */
  exports.prototype['deactivation_date'] = undefined;



  return exports;
}));


